# coding: utf-8

"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SearchRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'search_keyword': 'str',
        'user_ids': 'list[str]',
        'product': 'SearchRequestProduct',
        'date_filter': 'list[SearchRequestDateFilter]',
        'usernames': 'list[str]',
        'sort_column': 'str',
        'sort_order': 'str',
        'selectors': 'list[str]',
        '_from': 'str',
        'size': 'str',
        'is2_fa_enabled': 'bool'
    }

    attribute_map = {
        'enabled': 'enabled',
        'search_keyword': 'searchKeyword',
        'user_ids': 'userIds',
        'product': 'product',
        'date_filter': 'dateFilter',
        'usernames': 'usernames',
        'sort_column': 'sortColumn',
        'sort_order': 'sortOrder',
        'selectors': 'selectors',
        '_from': 'from',
        'size': 'size',
        'is2_fa_enabled': 'is2FAEnabled'
    }

    def __init__(self, enabled=None, search_keyword=None, user_ids=None, product=None, date_filter=None, usernames=None, sort_column=None, sort_order=None, selectors=None, _from=None, size=None, is2_fa_enabled=None):  # noqa: E501
        """SearchRequest - a model defined in Swagger"""  # noqa: E501
        self._enabled = None
        self._search_keyword = None
        self._user_ids = None
        self._product = None
        self._date_filter = None
        self._usernames = None
        self._sort_column = None
        self._sort_order = None
        self._selectors = None
        self.__from = None
        self._size = None
        self._is2_fa_enabled = None
        self.discriminator = None
        if enabled is not None:
            self.enabled = enabled
        if search_keyword is not None:
            self.search_keyword = search_keyword
        if user_ids is not None:
            self.user_ids = user_ids
        if product is not None:
            self.product = product
        if date_filter is not None:
            self.date_filter = date_filter
        if usernames is not None:
            self.usernames = usernames
        if sort_column is not None:
            self.sort_column = sort_column
        if sort_order is not None:
            self.sort_order = sort_order
        if selectors is not None:
            self.selectors = selectors
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size
        if is2_fa_enabled is not None:
            self.is2_fa_enabled = is2_fa_enabled

    @property
    def enabled(self):
        """Gets the enabled of this SearchRequest.  # noqa: E501

        Flag to indicate if the search functionality is enabled.  # noqa: E501

        :return: The enabled of this SearchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this SearchRequest.

        Flag to indicate if the search functionality is enabled.  # noqa: E501

        :param enabled: The enabled of this SearchRequest.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def search_keyword(self):
        """Gets the search_keyword of this SearchRequest.  # noqa: E501

        Keyword to search for in user data.  # noqa: E501

        :return: The search_keyword of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._search_keyword

    @search_keyword.setter
    def search_keyword(self, search_keyword):
        """Sets the search_keyword of this SearchRequest.

        Keyword to search for in user data.  # noqa: E501

        :param search_keyword: The search_keyword of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._search_keyword = search_keyword

    @property
    def user_ids(self):
        """Gets the user_ids of this SearchRequest.  # noqa: E501

        List of user IDs to include in the search.  # noqa: E501

        :return: The user_ids of this SearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_ids

    @user_ids.setter
    def user_ids(self, user_ids):
        """Sets the user_ids of this SearchRequest.

        List of user IDs to include in the search.  # noqa: E501

        :param user_ids: The user_ids of this SearchRequest.  # noqa: E501
        :type: list[str]
        """

        self._user_ids = user_ids

    @property
    def product(self):
        """Gets the product of this SearchRequest.  # noqa: E501


        :return: The product of this SearchRequest.  # noqa: E501
        :rtype: SearchRequestProduct
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SearchRequest.


        :param product: The product of this SearchRequest.  # noqa: E501
        :type: SearchRequestProduct
        """

        self._product = product

    @property
    def date_filter(self):
        """Gets the date_filter of this SearchRequest.  # noqa: E501

        List of date filters for the search.  # noqa: E501

        :return: The date_filter of this SearchRequest.  # noqa: E501
        :rtype: list[SearchRequestDateFilter]
        """
        return self._date_filter

    @date_filter.setter
    def date_filter(self, date_filter):
        """Sets the date_filter of this SearchRequest.

        List of date filters for the search.  # noqa: E501

        :param date_filter: The date_filter of this SearchRequest.  # noqa: E501
        :type: list[SearchRequestDateFilter]
        """

        self._date_filter = date_filter

    @property
    def usernames(self):
        """Gets the usernames of this SearchRequest.  # noqa: E501

        List of usernames to include in the search.  # noqa: E501

        :return: The usernames of this SearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._usernames

    @usernames.setter
    def usernames(self, usernames):
        """Sets the usernames of this SearchRequest.

        List of usernames to include in the search.  # noqa: E501

        :param usernames: The usernames of this SearchRequest.  # noqa: E501
        :type: list[str]
        """

        self._usernames = usernames

    @property
    def sort_column(self):
        """Gets the sort_column of this SearchRequest.  # noqa: E501

        Column to sort the search results by.  # noqa: E501

        :return: The sort_column of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._sort_column

    @sort_column.setter
    def sort_column(self, sort_column):
        """Sets the sort_column of this SearchRequest.

        Column to sort the search results by.  # noqa: E501

        :param sort_column: The sort_column of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._sort_column = sort_column

    @property
    def sort_order(self):
        """Gets the sort_order of this SearchRequest.  # noqa: E501

        Order to sort the search results (ascending or descending).  # noqa: E501

        :return: The sort_order of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this SearchRequest.

        Order to sort the search results (ascending or descending).  # noqa: E501

        :param sort_order: The sort_order of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._sort_order = sort_order

    @property
    def selectors(self):
        """Gets the selectors of this SearchRequest.  # noqa: E501

        List of selectors for the search.  # noqa: E501

        :return: The selectors of this SearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._selectors

    @selectors.setter
    def selectors(self, selectors):
        """Sets the selectors of this SearchRequest.

        List of selectors for the search.  # noqa: E501

        :param selectors: The selectors of this SearchRequest.  # noqa: E501
        :type: list[str]
        """

        self._selectors = selectors

    @property
    def _from(self):
        """Gets the _from of this SearchRequest.  # noqa: E501

        Starting point for paginated results.  # noqa: E501

        :return: The _from of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SearchRequest.

        Starting point for paginated results.  # noqa: E501

        :param _from: The _from of this SearchRequest.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this SearchRequest.  # noqa: E501

        Number of results to return per page.  # noqa: E501

        :return: The size of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SearchRequest.

        Number of results to return per page.  # noqa: E501

        :param size: The size of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def is2_fa_enabled(self):
        """Gets the is2_fa_enabled of this SearchRequest.  # noqa: E501

        Flag to indicate if 2FA is enabled for the users.  # noqa: E501

        :return: The is2_fa_enabled of this SearchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is2_fa_enabled

    @is2_fa_enabled.setter
    def is2_fa_enabled(self, is2_fa_enabled):
        """Sets the is2_fa_enabled of this SearchRequest.

        Flag to indicate if 2FA is enabled for the users.  # noqa: E501

        :param is2_fa_enabled: The is2_fa_enabled of this SearchRequest.  # noqa: E501
        :type: bool
        """

        self._is2_fa_enabled = is2_fa_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    tags-api

    These APIs enable tag management for candidates, offering functionalities to create, update, delete tags, and add or remove them from candidate profiles.  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.tags.candidates_api import CandidatesApi
from phenom.api.tags.tags_api import TagsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.tags.models.bad_request import BadRequest
from phenom.api.tags.models.bad_request_errors import BadRequestErrors
from phenom.api.tags.models.candidate_tags_association import CandidateTagsAssociation
from phenom.api.tags.models.create_tag_duplicate import CreateTagDuplicate
from phenom.api.tags.models.create_tag_request import CreateTagRequest
from phenom.api.tags.models.create_tag_response import CreateTagResponse
from phenom.api.tags.models.delete_tag_not_found import DeleteTagNotFound
from phenom.api.tags.models.get_tag_associations_response import GetTagAssociationsResponse
from phenom.api.tags.models.get_tag_associations_response_pagination import GetTagAssociationsResponsePagination
from phenom.api.tags.models.get_tags_response import GetTagsResponse
from phenom.api.tags.models.get_tags_response_data import GetTagsResponseData
from phenom.api.tags.models.get_tags_response_pagination import GetTagsResponsePagination
from phenom.api.tags.models.no_content_response import NoContentResponse
from phenom.api.tags.models.tag_failure import TagFailure
from phenom.api.tags.models.tag_response import TagResponse
from phenom.api.tags.models.update_tag_request import UpdateTagRequest



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectsResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'message': 'str',
        'timestamp': 'str',
        'data': 'list[GetProjectsResponseData]'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message',
        'timestamp': 'timestamp',
        'data': 'data'
    }

    def __init__(self, status=None, message=None, timestamp=None, data=None):  # noqa: E501
        """GetProjectsResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._message = None
        self._timestamp = None
        self._data = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if message is not None:
            self.message = message
        if timestamp is not None:
            self.timestamp = timestamp
        if data is not None:
            self.data = data

    @property
    def status(self):
        """Gets the status of this GetProjectsResponse.  # noqa: E501

        The status of the response.  # noqa: E501

        :return: The status of this GetProjectsResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetProjectsResponse.

        The status of the response.  # noqa: E501

        :param status: The status of this GetProjectsResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this GetProjectsResponse.  # noqa: E501

        A descriptive message associated with the response status.  # noqa: E501

        :return: The message of this GetProjectsResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this GetProjectsResponse.

        A descriptive message associated with the response status.  # noqa: E501

        :param message: The message of this GetProjectsResponse.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this GetProjectsResponse.  # noqa: E501

        The timestamp indicating when the response was generated.  # noqa: E501

        :return: The timestamp of this GetProjectsResponse.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this GetProjectsResponse.

        The timestamp indicating when the response was generated.  # noqa: E501

        :param timestamp: The timestamp of this GetProjectsResponse.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def data(self):
        """Gets the data of this GetProjectsResponse.  # noqa: E501

        An array containing details of projects.  # noqa: E501

        :return: The data of this GetProjectsResponse.  # noqa: E501
        :rtype: list[GetProjectsResponseData]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this GetProjectsResponse.

        An array containing details of projects.  # noqa: E501

        :param data: The data of this GetProjectsResponse.  # noqa: E501
        :type: list[GetProjectsResponseData]
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class InternalServerError(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'message': 'str',
        'timestamp': 'str'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message',
        'timestamp': 'timestamp'
    }

    def __init__(self, status=None, message=None, timestamp=None):  # noqa: E501
        """InternalServerError - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._message = None
        self._timestamp = None
        self.discriminator = None
        self.status = status
        self.message = message
        self.timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this InternalServerError.  # noqa: E501

        The status of the internal server error response.  # noqa: E501

        :return: The status of this InternalServerError.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InternalServerError.

        The status of the internal server error response.  # noqa: E501

        :param status: The status of this InternalServerError.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def message(self):
        """Gets the message of this InternalServerError.  # noqa: E501

        A descriptive message associated with the internal server error.  # noqa: E501

        :return: The message of this InternalServerError.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InternalServerError.

        A descriptive message associated with the internal server error.  # noqa: E501

        :param message: The message of this InternalServerError.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this InternalServerError.  # noqa: E501

        The timestamp indicating when the internal server error occurred.  # noqa: E501

        :return: The timestamp of this InternalServerError.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this InternalServerError.

        The timestamp indicating when the internal server error occurred.  # noqa: E501

        :param timestamp: The timestamp of this InternalServerError.  # noqa: E501
        :type: str
        """
        if timestamp is None:
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InternalServerError, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InternalServerError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.search.search_api import SearchApi
from phenom.api.recommendation.recommendations_api import RecommendationsApi
from phenom.api.jobactivities.job_category_api import JobCategoryApi
from phenom.api.jobactivities.job_attachments_api import JobAttachmentsApi
from phenom.api.jobactivities.job_notes_api import JobNotesApi
from phenom.api.jobactivities.hiring_team_api import HiringTeamApi
from phenom.api.jobquestionnarie.job_questionnaire_api import JobQuestionnaireApi
from phenom.api.jobquestionnarie.questionnaire_templates_api import QuestionnaireTemplatesApi
from phenom.api.jobsync.jobs_api import JobsApi

class Jobs(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def search_api(self):
        return SearchApi(self.__token, self.__gateway_url, self.__apikey)

    def recommendations_api(self):
        return RecommendationsApi(self.__token, self.__gateway_url, self.__apikey)

    def job_category_api(self):
        return JobCategoryApi(self.__token, self.__gateway_url, self.__apikey)

    def job_attachments_api(self):
        return JobAttachmentsApi(self.__token, self.__gateway_url, self.__apikey)

    def job_notes_api(self):
        return JobNotesApi(self.__token, self.__gateway_url, self.__apikey)

    def hiring_team_api(self):
        return HiringTeamApi(self.__token, self.__gateway_url, self.__apikey)

    def job_questionnaire_api(self):
        return JobQuestionnaireApi(self.__token, self.__gateway_url, self.__apikey)

    def questionnaire_templates_api(self):
        return QuestionnaireTemplatesApi(self.__token, self.__gateway_url, self.__apikey)

    def jobs_api(self):
        return JobsApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllWorkflowStatusResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status_id': 'str',
        'name': 'str',
        'status_code': 'str',
        'status_type': 'str',
        'associated_workflows': 'list[object]',
        'created_by_recruiter_info': 'GetAllWorkflowStatusResponseCreatedByRecruiterInfo',
        'created_date': 'str',
        'updated_date': 'str'
    }

    attribute_map = {
        'status_id': 'statusId',
        'name': 'name',
        'status_code': 'statusCode',
        'status_type': 'statusType',
        'associated_workflows': 'associatedWorkflows',
        'created_by_recruiter_info': 'createdByRecruiterInfo',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate'
    }

    def __init__(self, status_id=None, name=None, status_code=None, status_type=None, associated_workflows=None, created_by_recruiter_info=None, created_date=None, updated_date=None):  # noqa: E501
        """GetAllWorkflowStatusResponseData - a model defined in Swagger"""  # noqa: E501
        self._status_id = None
        self._name = None
        self._status_code = None
        self._status_type = None
        self._associated_workflows = None
        self._created_by_recruiter_info = None
        self._created_date = None
        self._updated_date = None
        self.discriminator = None
        self.status_id = status_id
        self.name = name
        self.status_code = status_code
        self.status_type = status_type
        if associated_workflows is not None:
            self.associated_workflows = associated_workflows
        self.created_by_recruiter_info = created_by_recruiter_info
        self.created_date = created_date
        self.updated_date = updated_date

    @property
    def status_id(self):
        """Gets the status_id of this GetAllWorkflowStatusResponseData.  # noqa: E501

        ID of the workflow status.  # noqa: E501

        :return: The status_id of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this GetAllWorkflowStatusResponseData.

        ID of the workflow status.  # noqa: E501

        :param status_id: The status_id of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def name(self):
        """Gets the name of this GetAllWorkflowStatusResponseData.  # noqa: E501

        Name of the workflow status.  # noqa: E501

        :return: The name of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GetAllWorkflowStatusResponseData.

        Name of the workflow status.  # noqa: E501

        :param name: The name of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def status_code(self):
        """Gets the status_code of this GetAllWorkflowStatusResponseData.  # noqa: E501

        Code associated with the workflow status.  # noqa: E501

        :return: The status_code of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this GetAllWorkflowStatusResponseData.

        Code associated with the workflow status.  # noqa: E501

        :param status_code: The status_code of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if status_code is None:
            raise ValueError("Invalid value for `status_code`, must not be `None`")  # noqa: E501

        self._status_code = status_code

    @property
    def status_type(self):
        """Gets the status_type of this GetAllWorkflowStatusResponseData.  # noqa: E501

        Type of the workflow status.  # noqa: E501

        :return: The status_type of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status_type

    @status_type.setter
    def status_type(self, status_type):
        """Sets the status_type of this GetAllWorkflowStatusResponseData.

        Type of the workflow status.  # noqa: E501

        :param status_type: The status_type of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if status_type is None:
            raise ValueError("Invalid value for `status_type`, must not be `None`")  # noqa: E501

        self._status_type = status_type

    @property
    def associated_workflows(self):
        """Gets the associated_workflows of this GetAllWorkflowStatusResponseData.  # noqa: E501

        List of associated workflows.  # noqa: E501

        :return: The associated_workflows of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: list[object]
        """
        return self._associated_workflows

    @associated_workflows.setter
    def associated_workflows(self, associated_workflows):
        """Sets the associated_workflows of this GetAllWorkflowStatusResponseData.

        List of associated workflows.  # noqa: E501

        :param associated_workflows: The associated_workflows of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: list[object]
        """

        self._associated_workflows = associated_workflows

    @property
    def created_by_recruiter_info(self):
        """Gets the created_by_recruiter_info of this GetAllWorkflowStatusResponseData.  # noqa: E501


        :return: The created_by_recruiter_info of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: GetAllWorkflowStatusResponseCreatedByRecruiterInfo
        """
        return self._created_by_recruiter_info

    @created_by_recruiter_info.setter
    def created_by_recruiter_info(self, created_by_recruiter_info):
        """Sets the created_by_recruiter_info of this GetAllWorkflowStatusResponseData.


        :param created_by_recruiter_info: The created_by_recruiter_info of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: GetAllWorkflowStatusResponseCreatedByRecruiterInfo
        """
        if created_by_recruiter_info is None:
            raise ValueError("Invalid value for `created_by_recruiter_info`, must not be `None`")  # noqa: E501

        self._created_by_recruiter_info = created_by_recruiter_info

    @property
    def created_date(self):
        """Gets the created_date of this GetAllWorkflowStatusResponseData.  # noqa: E501

        Date when the status was created.  # noqa: E501

        :return: The created_date of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetAllWorkflowStatusResponseData.

        Date when the status was created.  # noqa: E501

        :param created_date: The created_date of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this GetAllWorkflowStatusResponseData.  # noqa: E501

        Date when the status was last updated.  # noqa: E501

        :return: The updated_date of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetAllWorkflowStatusResponseData.

        Date when the status was last updated.  # noqa: E501

        :param updated_date: The updated_date of this GetAllWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if updated_date is None:
            raise ValueError("Invalid value for `updated_date`, must not be `None`")  # noqa: E501

        self._updated_date = updated_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllWorkflowStatusResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllWorkflowStatusResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsMultiLocation(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'location': 'str',
        'state': 'str',
        'country': 'str',
        'latitude': 'str',
        'longitude': 'str',
        'postal_code': 'str',
        'location_id': 'str',
        'address': 'str',
        'city_country': 'str',
        'external_location': 'str',
        'city_state': 'str',
        'map_query_location': 'str',
        'state_country': 'str',
        'city_state_country': 'str',
        'lat_long': 'JobDetailsLatLong'
    }

    attribute_map = {
        'city': 'city',
        'location': 'location',
        'state': 'state',
        'country': 'country',
        'latitude': 'latitude',
        'longitude': 'longitude',
        'postal_code': 'postalCode',
        'location_id': 'locationId',
        'address': 'address',
        'city_country': 'cityCountry',
        'external_location': 'externalLocation',
        'city_state': 'cityState',
        'map_query_location': 'mapQueryLocation',
        'state_country': 'stateCountry',
        'city_state_country': 'cityStateCountry',
        'lat_long': 'latLong'
    }

    def __init__(self, city=None, location=None, state=None, country=None, latitude=None, longitude=None, postal_code=None, location_id=None, address=None, city_country=None, external_location=None, city_state=None, map_query_location=None, state_country=None, city_state_country=None, lat_long=None):  # noqa: E501
        """JobDetailsMultiLocation - a model defined in Swagger"""  # noqa: E501
        self._city = None
        self._location = None
        self._state = None
        self._country = None
        self._latitude = None
        self._longitude = None
        self._postal_code = None
        self._location_id = None
        self._address = None
        self._city_country = None
        self._external_location = None
        self._city_state = None
        self._map_query_location = None
        self._state_country = None
        self._city_state_country = None
        self._lat_long = None
        self.discriminator = None
        if city is not None:
            self.city = city
        if location is not None:
            self.location = location
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude
        if postal_code is not None:
            self.postal_code = postal_code
        if location_id is not None:
            self.location_id = location_id
        if address is not None:
            self.address = address
        if city_country is not None:
            self.city_country = city_country
        if external_location is not None:
            self.external_location = external_location
        if city_state is not None:
            self.city_state = city_state
        if map_query_location is not None:
            self.map_query_location = map_query_location
        if state_country is not None:
            self.state_country = state_country
        if city_state_country is not None:
            self.city_state_country = city_state_country
        if lat_long is not None:
            self.lat_long = lat_long

    @property
    def city(self):
        """Gets the city of this JobDetailsMultiLocation.  # noqa: E501

        Name of the city where the job is available.  # noqa: E501

        :return: The city of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this JobDetailsMultiLocation.

        Name of the city where the job is available.  # noqa: E501

        :param city: The city of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def location(self):
        """Gets the location of this JobDetailsMultiLocation.  # noqa: E501

        Location of the job.  # noqa: E501

        :return: The location of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this JobDetailsMultiLocation.

        Location of the job.  # noqa: E501

        :param location: The location of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def state(self):
        """Gets the state of this JobDetailsMultiLocation.  # noqa: E501

        Name of the state where the job is available.  # noqa: E501

        :return: The state of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this JobDetailsMultiLocation.

        Name of the state where the job is available.  # noqa: E501

        :param state: The state of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this JobDetailsMultiLocation.  # noqa: E501

        Name of the country where the job is available.  # noqa: E501

        :return: The country of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this JobDetailsMultiLocation.

        Name of the country where the job is available.  # noqa: E501

        :param country: The country of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def latitude(self):
        """Gets the latitude of this JobDetailsMultiLocation.  # noqa: E501

        Latitude of the place where the job is available.  # noqa: E501

        :return: The latitude of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this JobDetailsMultiLocation.

        Latitude of the place where the job is available.  # noqa: E501

        :param latitude: The latitude of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this JobDetailsMultiLocation.  # noqa: E501

        Longitude of the place where the job is available.  # noqa: E501

        :return: The longitude of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this JobDetailsMultiLocation.

        Longitude of the place where the job is available.  # noqa: E501

        :param longitude: The longitude of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._longitude = longitude

    @property
    def postal_code(self):
        """Gets the postal_code of this JobDetailsMultiLocation.  # noqa: E501

        Postal code of the place where the job is available.  # noqa: E501

        :return: The postal_code of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this JobDetailsMultiLocation.

        Postal code of the place where the job is available.  # noqa: E501

        :param postal_code: The postal_code of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def location_id(self):
        """Gets the location_id of this JobDetailsMultiLocation.  # noqa: E501

        Location ID of the place where the job is available.  # noqa: E501

        :return: The location_id of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this JobDetailsMultiLocation.

        Location ID of the place where the job is available.  # noqa: E501

        :param location_id: The location_id of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def address(self):
        """Gets the address of this JobDetailsMultiLocation.  # noqa: E501

        Address of the place where the job is available.  # noqa: E501

        :return: The address of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this JobDetailsMultiLocation.

        Address of the place where the job is available.  # noqa: E501

        :param address: The address of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def city_country(self):
        """Gets the city_country of this JobDetailsMultiLocation.  # noqa: E501

        City Country of the place where the job is available.  # noqa: E501

        :return: The city_country of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._city_country

    @city_country.setter
    def city_country(self, city_country):
        """Sets the city_country of this JobDetailsMultiLocation.

        City Country of the place where the job is available.  # noqa: E501

        :param city_country: The city_country of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._city_country = city_country

    @property
    def external_location(self):
        """Gets the external_location of this JobDetailsMultiLocation.  # noqa: E501

        External location.  # noqa: E501

        :return: The external_location of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._external_location

    @external_location.setter
    def external_location(self, external_location):
        """Sets the external_location of this JobDetailsMultiLocation.

        External location.  # noqa: E501

        :param external_location: The external_location of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._external_location = external_location

    @property
    def city_state(self):
        """Gets the city_state of this JobDetailsMultiLocation.  # noqa: E501

        City state name.  # noqa: E501

        :return: The city_state of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._city_state

    @city_state.setter
    def city_state(self, city_state):
        """Sets the city_state of this JobDetailsMultiLocation.

        City state name.  # noqa: E501

        :param city_state: The city_state of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._city_state = city_state

    @property
    def map_query_location(self):
        """Gets the map_query_location of this JobDetailsMultiLocation.  # noqa: E501

        The map query location.  # noqa: E501

        :return: The map_query_location of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._map_query_location

    @map_query_location.setter
    def map_query_location(self, map_query_location):
        """Sets the map_query_location of this JobDetailsMultiLocation.

        The map query location.  # noqa: E501

        :param map_query_location: The map_query_location of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._map_query_location = map_query_location

    @property
    def state_country(self):
        """Gets the state_country of this JobDetailsMultiLocation.  # noqa: E501

        The state country name.  # noqa: E501

        :return: The state_country of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._state_country

    @state_country.setter
    def state_country(self, state_country):
        """Sets the state_country of this JobDetailsMultiLocation.

        The state country name.  # noqa: E501

        :param state_country: The state_country of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._state_country = state_country

    @property
    def city_state_country(self):
        """Gets the city_state_country of this JobDetailsMultiLocation.  # noqa: E501

        The city state country name.  # noqa: E501

        :return: The city_state_country of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: str
        """
        return self._city_state_country

    @city_state_country.setter
    def city_state_country(self, city_state_country):
        """Sets the city_state_country of this JobDetailsMultiLocation.

        The city state country name.  # noqa: E501

        :param city_state_country: The city_state_country of this JobDetailsMultiLocation.  # noqa: E501
        :type: str
        """

        self._city_state_country = city_state_country

    @property
    def lat_long(self):
        """Gets the lat_long of this JobDetailsMultiLocation.  # noqa: E501


        :return: The lat_long of this JobDetailsMultiLocation.  # noqa: E501
        :rtype: JobDetailsLatLong
        """
        return self._lat_long

    @lat_long.setter
    def lat_long(self, lat_long):
        """Sets the lat_long of this JobDetailsMultiLocation.


        :param lat_long: The lat_long of this JobDetailsMultiLocation.  # noqa: E501
        :type: JobDetailsLatLong
        """

        self._lat_long = lat_long

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsMultiLocation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsMultiLocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EnableOneWayInterviewRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_id': 'str',
        'interview_expiry_days': 'float',
        'reminder_days': 'float',
        'enable_status': 'bool',
        'questionnaire_id': 'str'
    }

    attribute_map = {
        'job_id': 'jobId',
        'interview_expiry_days': 'interviewExpiryDays',
        'reminder_days': 'reminderDays',
        'enable_status': 'enableStatus',
        'questionnaire_id': 'questionnaireId'
    }

    def __init__(self, job_id=None, interview_expiry_days=None, reminder_days=None, enable_status=None, questionnaire_id=None):  # noqa: E501
        """EnableOneWayInterviewRequest - a model defined in Swagger"""  # noqa: E501
        self._job_id = None
        self._interview_expiry_days = None
        self._reminder_days = None
        self._enable_status = None
        self._questionnaire_id = None
        self.discriminator = None
        self.job_id = job_id
        self.interview_expiry_days = interview_expiry_days
        self.reminder_days = reminder_days
        self.enable_status = enable_status
        self.questionnaire_id = questionnaire_id

    @property
    def job_id(self):
        """Gets the job_id of this EnableOneWayInterviewRequest.  # noqa: E501

        JobId of a Job.  # noqa: E501

        :return: The job_id of this EnableOneWayInterviewRequest.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this EnableOneWayInterviewRequest.

        JobId of a Job.  # noqa: E501

        :param job_id: The job_id of this EnableOneWayInterviewRequest.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    @property
    def interview_expiry_days(self):
        """Gets the interview_expiry_days of this EnableOneWayInterviewRequest.  # noqa: E501

        If an invite is sent for a job, indicates the expiry of the invitation.  # noqa: E501

        :return: The interview_expiry_days of this EnableOneWayInterviewRequest.  # noqa: E501
        :rtype: float
        """
        return self._interview_expiry_days

    @interview_expiry_days.setter
    def interview_expiry_days(self, interview_expiry_days):
        """Sets the interview_expiry_days of this EnableOneWayInterviewRequest.

        If an invite is sent for a job, indicates the expiry of the invitation.  # noqa: E501

        :param interview_expiry_days: The interview_expiry_days of this EnableOneWayInterviewRequest.  # noqa: E501
        :type: float
        """
        if interview_expiry_days is None:
            raise ValueError("Invalid value for `interview_expiry_days`, must not be `None`")  # noqa: E501

        self._interview_expiry_days = interview_expiry_days

    @property
    def reminder_days(self):
        """Gets the reminder_days of this EnableOneWayInterviewRequest.  # noqa: E501

        If an invite is sent for a job, indicates the reminder to be sent before the expiry days.  # noqa: E501

        :return: The reminder_days of this EnableOneWayInterviewRequest.  # noqa: E501
        :rtype: float
        """
        return self._reminder_days

    @reminder_days.setter
    def reminder_days(self, reminder_days):
        """Sets the reminder_days of this EnableOneWayInterviewRequest.

        If an invite is sent for a job, indicates the reminder to be sent before the expiry days.  # noqa: E501

        :param reminder_days: The reminder_days of this EnableOneWayInterviewRequest.  # noqa: E501
        :type: float
        """
        if reminder_days is None:
            raise ValueError("Invalid value for `reminder_days`, must not be `None`")  # noqa: E501

        self._reminder_days = reminder_days

    @property
    def enable_status(self):
        """Gets the enable_status of this EnableOneWayInterviewRequest.  # noqa: E501

        Send true to enable one way interview, false to disable.  # noqa: E501

        :return: The enable_status of this EnableOneWayInterviewRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_status

    @enable_status.setter
    def enable_status(self, enable_status):
        """Sets the enable_status of this EnableOneWayInterviewRequest.

        Send true to enable one way interview, false to disable.  # noqa: E501

        :param enable_status: The enable_status of this EnableOneWayInterviewRequest.  # noqa: E501
        :type: bool
        """
        if enable_status is None:
            raise ValueError("Invalid value for `enable_status`, must not be `None`")  # noqa: E501

        self._enable_status = enable_status

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this EnableOneWayInterviewRequest.  # noqa: E501

        Questionnaire id of the the questionnaire.  # noqa: E501

        :return: The questionnaire_id of this EnableOneWayInterviewRequest.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this EnableOneWayInterviewRequest.

        Questionnaire id of the the questionnaire.  # noqa: E501

        :param questionnaire_id: The questionnaire_id of this EnableOneWayInterviewRequest.  # noqa: E501
        :type: str
        """
        if questionnaire_id is None:
            raise ValueError("Invalid value for `questionnaire_id`, must not be `None`")  # noqa: E501

        self._questionnaire_id = questionnaire_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnableOneWayInterviewRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableOneWayInterviewRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'int',
        'skills': 'list[str]',
        'skill_ranking': 'list[JobResponseSkillRanking]',
        'job_teaser': 'str',
        'job_experience': 'JobResponseJobExperience',
        'language': 'str',
        'requirement_sentences': 'list[str]',
        'responsibility_sentences': 'list[str]',
        'experience_sentences': 'list[str]',
        'soft_skills_sentences': 'list[str]',
        'skills_sentences': 'list[str]',
        'education_sentences': 'list[str]',
        'job_zone': 'int',
        'onet': 'list[JobResponseOnet]',
        'job_preferred_languages': 'str',
        'job_type_fields': 'JobResponseJobTypeFields',
        'clean_title': 'str',
        'language_fullform': 'str',
        'job_domain': 'str'
    }

    attribute_map = {
        'status': 'status',
        'skills': 'skills',
        'skill_ranking': 'skillRanking',
        'job_teaser': 'jobTeaser',
        'job_experience': 'jobExperience',
        'language': 'language',
        'requirement_sentences': 'requirementSentences',
        'responsibility_sentences': 'responsibilitySentences',
        'experience_sentences': 'experienceSentences',
        'soft_skills_sentences': 'softSkillsSentences',
        'skills_sentences': 'skillsSentences',
        'education_sentences': 'educationSentences',
        'job_zone': 'jobZone',
        'onet': 'onet',
        'job_preferred_languages': 'jobPreferredLanguages',
        'job_type_fields': 'jobTypeFields',
        'clean_title': 'cleanTitle',
        'language_fullform': 'languageFullform',
        'job_domain': 'jobDomain'
    }

    def __init__(self, status=None, skills=None, skill_ranking=None, job_teaser=None, job_experience=None, language=None, requirement_sentences=None, responsibility_sentences=None, experience_sentences=None, soft_skills_sentences=None, skills_sentences=None, education_sentences=None, job_zone=None, onet=None, job_preferred_languages=None, job_type_fields=None, clean_title=None, language_fullform=None, job_domain=None):  # noqa: E501
        """JobResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._skills = None
        self._skill_ranking = None
        self._job_teaser = None
        self._job_experience = None
        self._language = None
        self._requirement_sentences = None
        self._responsibility_sentences = None
        self._experience_sentences = None
        self._soft_skills_sentences = None
        self._skills_sentences = None
        self._education_sentences = None
        self._job_zone = None
        self._onet = None
        self._job_preferred_languages = None
        self._job_type_fields = None
        self._clean_title = None
        self._language_fullform = None
        self._job_domain = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if skills is not None:
            self.skills = skills
        if skill_ranking is not None:
            self.skill_ranking = skill_ranking
        if job_teaser is not None:
            self.job_teaser = job_teaser
        if job_experience is not None:
            self.job_experience = job_experience
        if language is not None:
            self.language = language
        if requirement_sentences is not None:
            self.requirement_sentences = requirement_sentences
        if responsibility_sentences is not None:
            self.responsibility_sentences = responsibility_sentences
        if experience_sentences is not None:
            self.experience_sentences = experience_sentences
        if soft_skills_sentences is not None:
            self.soft_skills_sentences = soft_skills_sentences
        if skills_sentences is not None:
            self.skills_sentences = skills_sentences
        if education_sentences is not None:
            self.education_sentences = education_sentences
        if job_zone is not None:
            self.job_zone = job_zone
        if onet is not None:
            self.onet = onet
        if job_preferred_languages is not None:
            self.job_preferred_languages = job_preferred_languages
        if job_type_fields is not None:
            self.job_type_fields = job_type_fields
        if clean_title is not None:
            self.clean_title = clean_title
        if language_fullform is not None:
            self.language_fullform = language_fullform
        if job_domain is not None:
            self.job_domain = job_domain

    @property
    def status(self):
        """Gets the status of this JobResponse.  # noqa: E501


        :return: The status of this JobResponse.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobResponse.


        :param status: The status of this JobResponse.  # noqa: E501
        :type: int
        """

        self._status = status

    @property
    def skills(self):
        """Gets the skills of this JobResponse.  # noqa: E501

        All extracted skills deemed important by skills importance.  # noqa: E501

        :return: The skills of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """Sets the skills of this JobResponse.

        All extracted skills deemed important by skills importance.  # noqa: E501

        :param skills: The skills of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._skills = skills

    @property
    def skill_ranking(self):
        """Gets the skill_ranking of this JobResponse.  # noqa: E501

        Importantness of extracted skills.  # noqa: E501

        :return: The skill_ranking of this JobResponse.  # noqa: E501
        :rtype: list[JobResponseSkillRanking]
        """
        return self._skill_ranking

    @skill_ranking.setter
    def skill_ranking(self, skill_ranking):
        """Sets the skill_ranking of this JobResponse.

        Importantness of extracted skills.  # noqa: E501

        :param skill_ranking: The skill_ranking of this JobResponse.  # noqa: E501
        :type: list[JobResponseSkillRanking]
        """

        self._skill_ranking = skill_ranking

    @property
    def job_teaser(self):
        """Gets the job_teaser of this JobResponse.  # noqa: E501

        Job teaser from description.  # noqa: E501

        :return: The job_teaser of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._job_teaser

    @job_teaser.setter
    def job_teaser(self, job_teaser):
        """Sets the job_teaser of this JobResponse.

        Job teaser from description.  # noqa: E501

        :param job_teaser: The job_teaser of this JobResponse.  # noqa: E501
        :type: str
        """

        self._job_teaser = job_teaser

    @property
    def job_experience(self):
        """Gets the job_experience of this JobResponse.  # noqa: E501


        :return: The job_experience of this JobResponse.  # noqa: E501
        :rtype: JobResponseJobExperience
        """
        return self._job_experience

    @job_experience.setter
    def job_experience(self, job_experience):
        """Sets the job_experience of this JobResponse.


        :param job_experience: The job_experience of this JobResponse.  # noqa: E501
        :type: JobResponseJobExperience
        """

        self._job_experience = job_experience

    @property
    def language(self):
        """Gets the language of this JobResponse.  # noqa: E501

        Job language.  # noqa: E501

        :return: The language of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this JobResponse.

        Job language.  # noqa: E501

        :param language: The language of this JobResponse.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def requirement_sentences(self):
        """Gets the requirement_sentences of this JobResponse.  # noqa: E501

        All requirement sentences.  # noqa: E501

        :return: The requirement_sentences of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._requirement_sentences

    @requirement_sentences.setter
    def requirement_sentences(self, requirement_sentences):
        """Sets the requirement_sentences of this JobResponse.

        All requirement sentences.  # noqa: E501

        :param requirement_sentences: The requirement_sentences of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._requirement_sentences = requirement_sentences

    @property
    def responsibility_sentences(self):
        """Gets the responsibility_sentences of this JobResponse.  # noqa: E501

        All responsibility sentences.  # noqa: E501

        :return: The responsibility_sentences of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._responsibility_sentences

    @responsibility_sentences.setter
    def responsibility_sentences(self, responsibility_sentences):
        """Sets the responsibility_sentences of this JobResponse.

        All responsibility sentences.  # noqa: E501

        :param responsibility_sentences: The responsibility_sentences of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._responsibility_sentences = responsibility_sentences

    @property
    def experience_sentences(self):
        """Gets the experience_sentences of this JobResponse.  # noqa: E501

        All experience sentences.  # noqa: E501

        :return: The experience_sentences of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._experience_sentences

    @experience_sentences.setter
    def experience_sentences(self, experience_sentences):
        """Sets the experience_sentences of this JobResponse.

        All experience sentences.  # noqa: E501

        :param experience_sentences: The experience_sentences of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._experience_sentences = experience_sentences

    @property
    def soft_skills_sentences(self):
        """Gets the soft_skills_sentences of this JobResponse.  # noqa: E501

        All soft skill sentences.  # noqa: E501

        :return: The soft_skills_sentences of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._soft_skills_sentences

    @soft_skills_sentences.setter
    def soft_skills_sentences(self, soft_skills_sentences):
        """Sets the soft_skills_sentences of this JobResponse.

        All soft skill sentences.  # noqa: E501

        :param soft_skills_sentences: The soft_skills_sentences of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._soft_skills_sentences = soft_skills_sentences

    @property
    def skills_sentences(self):
        """Gets the skills_sentences of this JobResponse.  # noqa: E501

        All required skills sentences.  # noqa: E501

        :return: The skills_sentences of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills_sentences

    @skills_sentences.setter
    def skills_sentences(self, skills_sentences):
        """Sets the skills_sentences of this JobResponse.

        All required skills sentences.  # noqa: E501

        :param skills_sentences: The skills_sentences of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._skills_sentences = skills_sentences

    @property
    def education_sentences(self):
        """Gets the education_sentences of this JobResponse.  # noqa: E501

        All education/degree related sentences.  # noqa: E501

        :return: The education_sentences of this JobResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._education_sentences

    @education_sentences.setter
    def education_sentences(self, education_sentences):
        """Sets the education_sentences of this JobResponse.

        All education/degree related sentences.  # noqa: E501

        :param education_sentences: The education_sentences of this JobResponse.  # noqa: E501
        :type: list[str]
        """

        self._education_sentences = education_sentences

    @property
    def job_zone(self):
        """Gets the job_zone of this JobResponse.  # noqa: E501

        Job zone.  # noqa: E501

        :return: The job_zone of this JobResponse.  # noqa: E501
        :rtype: int
        """
        return self._job_zone

    @job_zone.setter
    def job_zone(self, job_zone):
        """Sets the job_zone of this JobResponse.

        Job zone.  # noqa: E501

        :param job_zone: The job_zone of this JobResponse.  # noqa: E501
        :type: int
        """

        self._job_zone = job_zone

    @property
    def onet(self):
        """Gets the onet of this JobResponse.  # noqa: E501

        O*NET information containing onet code, title and score.  # noqa: E501

        :return: The onet of this JobResponse.  # noqa: E501
        :rtype: list[JobResponseOnet]
        """
        return self._onet

    @onet.setter
    def onet(self, onet):
        """Sets the onet of this JobResponse.

        O*NET information containing onet code, title and score.  # noqa: E501

        :param onet: The onet of this JobResponse.  # noqa: E501
        :type: list[JobResponseOnet]
        """

        self._onet = onet

    @property
    def job_preferred_languages(self):
        """Gets the job_preferred_languages of this JobResponse.  # noqa: E501

        Preferred languages mentioned in the job description.  # noqa: E501

        :return: The job_preferred_languages of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._job_preferred_languages

    @job_preferred_languages.setter
    def job_preferred_languages(self, job_preferred_languages):
        """Sets the job_preferred_languages of this JobResponse.

        Preferred languages mentioned in the job description.  # noqa: E501

        :param job_preferred_languages: The job_preferred_languages of this JobResponse.  # noqa: E501
        :type: str
        """

        self._job_preferred_languages = job_preferred_languages

    @property
    def job_type_fields(self):
        """Gets the job_type_fields of this JobResponse.  # noqa: E501


        :return: The job_type_fields of this JobResponse.  # noqa: E501
        :rtype: JobResponseJobTypeFields
        """
        return self._job_type_fields

    @job_type_fields.setter
    def job_type_fields(self, job_type_fields):
        """Sets the job_type_fields of this JobResponse.


        :param job_type_fields: The job_type_fields of this JobResponse.  # noqa: E501
        :type: JobResponseJobTypeFields
        """

        self._job_type_fields = job_type_fields

    @property
    def clean_title(self):
        """Gets the clean_title of this JobResponse.  # noqa: E501

        Noise free title.  # noqa: E501

        :return: The clean_title of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._clean_title

    @clean_title.setter
    def clean_title(self, clean_title):
        """Sets the clean_title of this JobResponse.

        Noise free title.  # noqa: E501

        :param clean_title: The clean_title of this JobResponse.  # noqa: E501
        :type: str
        """

        self._clean_title = clean_title

    @property
    def language_fullform(self):
        """Gets the language_fullform of this JobResponse.  # noqa: E501

        Job Language full form.  # noqa: E501

        :return: The language_fullform of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._language_fullform

    @language_fullform.setter
    def language_fullform(self, language_fullform):
        """Sets the language_fullform of this JobResponse.

        Job Language full form.  # noqa: E501

        :param language_fullform: The language_fullform of this JobResponse.  # noqa: E501
        :type: str
        """

        self._language_fullform = language_fullform

    @property
    def job_domain(self):
        """Gets the job_domain of this JobResponse.  # noqa: E501

        Job domain.  # noqa: E501

        :return: The job_domain of this JobResponse.  # noqa: E501
        :rtype: str
        """
        return self._job_domain

    @job_domain.setter
    def job_domain(self, job_domain):
        """Sets the job_domain of this JobResponse.

        Job domain.  # noqa: E501

        :param job_domain: The job_domain of this JobResponse.  # noqa: E501
        :type: str
        """

        self._job_domain = job_domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobs-questionnarie-api

    These APIs streamline question management, providing tools to create, delete, and update questions. Additionally, they offer functionality to attach question lists to specific job profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateQuestionnaireTemplateRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'questionnaire_name': 'str',
        'job_category': 'str',
        'as_default': 'bool',
        'auto_assign_to_jobs': 'bool',
        'template_type': 'str',
        'pre_screening_questions': 'list[UpdateQuestionnaireTemplateRequestPreScreeningQuestions]'
    }

    attribute_map = {
        'questionnaire_name': 'questionnaireName',
        'job_category': 'jobCategory',
        'as_default': 'asDefault',
        'auto_assign_to_jobs': 'autoAssignToJobs',
        'template_type': 'templateType',
        'pre_screening_questions': 'preScreeningQuestions'
    }

    def __init__(self, questionnaire_name=None, job_category=None, as_default=None, auto_assign_to_jobs=None, template_type=None, pre_screening_questions=None):  # noqa: E501
        """UpdateQuestionnaireTemplateRequest - a model defined in Swagger"""  # noqa: E501
        self._questionnaire_name = None
        self._job_category = None
        self._as_default = None
        self._auto_assign_to_jobs = None
        self._template_type = None
        self._pre_screening_questions = None
        self.discriminator = None
        self.questionnaire_name = questionnaire_name
        self.job_category = job_category
        self.as_default = as_default
        self.auto_assign_to_jobs = auto_assign_to_jobs
        self.template_type = template_type
        self.pre_screening_questions = pre_screening_questions

    @property
    def questionnaire_name(self):
        """Gets the questionnaire_name of this UpdateQuestionnaireTemplateRequest.  # noqa: E501

        The name of the updated questionnaire template.  # noqa: E501

        :return: The questionnaire_name of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_name

    @questionnaire_name.setter
    def questionnaire_name(self, questionnaire_name):
        """Sets the questionnaire_name of this UpdateQuestionnaireTemplateRequest.

        The name of the updated questionnaire template.  # noqa: E501

        :param questionnaire_name: The questionnaire_name of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :type: str
        """
        if questionnaire_name is None:
            raise ValueError("Invalid value for `questionnaire_name`, must not be `None`")  # noqa: E501

        self._questionnaire_name = questionnaire_name

    @property
    def job_category(self):
        """Gets the job_category of this UpdateQuestionnaireTemplateRequest.  # noqa: E501

        The category of the job associated with the updated template.  # noqa: E501

        :return: The job_category of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._job_category

    @job_category.setter
    def job_category(self, job_category):
        """Sets the job_category of this UpdateQuestionnaireTemplateRequest.

        The category of the job associated with the updated template.  # noqa: E501

        :param job_category: The job_category of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :type: str
        """
        if job_category is None:
            raise ValueError("Invalid value for `job_category`, must not be `None`")  # noqa: E501

        self._job_category = job_category

    @property
    def as_default(self):
        """Gets the as_default of this UpdateQuestionnaireTemplateRequest.  # noqa: E501

        A boolean indicating whether the updated template is set as the default.  # noqa: E501

        :return: The as_default of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._as_default

    @as_default.setter
    def as_default(self, as_default):
        """Sets the as_default of this UpdateQuestionnaireTemplateRequest.

        A boolean indicating whether the updated template is set as the default.  # noqa: E501

        :param as_default: The as_default of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :type: bool
        """
        if as_default is None:
            raise ValueError("Invalid value for `as_default`, must not be `None`")  # noqa: E501

        self._as_default = as_default

    @property
    def auto_assign_to_jobs(self):
        """Gets the auto_assign_to_jobs of this UpdateQuestionnaireTemplateRequest.  # noqa: E501

        A boolean indicating whether the updated template is automatically assigned to jobs.  # noqa: E501

        :return: The auto_assign_to_jobs of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_assign_to_jobs

    @auto_assign_to_jobs.setter
    def auto_assign_to_jobs(self, auto_assign_to_jobs):
        """Sets the auto_assign_to_jobs of this UpdateQuestionnaireTemplateRequest.

        A boolean indicating whether the updated template is automatically assigned to jobs.  # noqa: E501

        :param auto_assign_to_jobs: The auto_assign_to_jobs of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :type: bool
        """
        if auto_assign_to_jobs is None:
            raise ValueError("Invalid value for `auto_assign_to_jobs`, must not be `None`")  # noqa: E501

        self._auto_assign_to_jobs = auto_assign_to_jobs

    @property
    def template_type(self):
        """Gets the template_type of this UpdateQuestionnaireTemplateRequest.  # noqa: E501

        The type of the updated template.  # noqa: E501

        :return: The template_type of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_type

    @template_type.setter
    def template_type(self, template_type):
        """Sets the template_type of this UpdateQuestionnaireTemplateRequest.

        The type of the updated template.  # noqa: E501

        :param template_type: The template_type of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :type: str
        """
        if template_type is None:
            raise ValueError("Invalid value for `template_type`, must not be `None`")  # noqa: E501

        self._template_type = template_type

    @property
    def pre_screening_questions(self):
        """Gets the pre_screening_questions of this UpdateQuestionnaireTemplateRequest.  # noqa: E501


        :return: The pre_screening_questions of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :rtype: list[UpdateQuestionnaireTemplateRequestPreScreeningQuestions]
        """
        return self._pre_screening_questions

    @pre_screening_questions.setter
    def pre_screening_questions(self, pre_screening_questions):
        """Sets the pre_screening_questions of this UpdateQuestionnaireTemplateRequest.


        :param pre_screening_questions: The pre_screening_questions of this UpdateQuestionnaireTemplateRequest.  # noqa: E501
        :type: list[UpdateQuestionnaireTemplateRequestPreScreeningQuestions]
        """
        if pre_screening_questions is None:
            raise ValueError("Invalid value for `pre_screening_questions`, must not be `None`")  # noqa: E501

        self._pre_screening_questions = pre_screening_questions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateQuestionnaireTemplateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateQuestionnaireTemplateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ErrorResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'response': 'ErrorResponseResponse'
    }

    attribute_map = {
        'response': 'response'
    }

    def __init__(self, response=None):  # noqa: E501
        """ErrorResponse - a model defined in Swagger"""  # noqa: E501
        self._response = None
        self.discriminator = None
        if response is not None:
            self.response = response

    @property
    def response(self):
        """Gets the response of this ErrorResponse.  # noqa: E501


        :return: The response of this ErrorResponse.  # noqa: E501
        :rtype: ErrorResponseResponse
        """
        return self._response

    @response.setter
    def response(self, response):
        """Sets the response of this ErrorResponse.


        :param response: The response of this ErrorResponse.  # noqa: E501
        :type: ErrorResponseResponse
        """

        self._response = response

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ErrorResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.employees.employee_profile_api import EmployeeProfileApi
from phenom.api.employees.employee_preferences_api import EmployeePreferencesApi
from phenom.api.employeescourses.employee_courses_api import EmployeeCoursesApi
from phenom.api.employeesreferral.employee_referrals_api import EmployeeReferralsApi
from phenom.api.employeescareerpath.employee_career_path_api import EmployeeCareerPathApi

from phenom.api.exsearch.employee_search_api import EmployeeSearchApi
from phenom.api.exsearch.mentor_api import MentorApi

class Employees(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def employee_profile_api(self):
        return EmployeeProfileApi(self.__token, self.__gateway_url, self.__apikey)

    def employee_preferences_api(self):
        return EmployeePreferencesApi(self.__token, self.__gateway_url, self.__apikey)

    def employee_courses_api(self):
        return EmployeeCoursesApi(self.__token, self.__gateway_url, self.__apikey)

    def employee_referrals_api(self):
        return EmployeeReferralsApi(self.__token, self.__gateway_url, self.__apikey)

    def employee_career_path_api(self):
        return EmployeeCareerPathApi(self.__token, self.__gateway_url, self.__apikey)

    def employee_search_api(self):
        return EmployeeSearchApi(self.__token, self.__gateway_url, self.__apikey)

    def mentor_api(self):
        return MentorApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

# flake8: noqa

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.videoplatform.candidate_invite_api import CandidateInviteApi
from phenom.api.videoplatform.evaluations_api import EvaluationsApi
from phenom.api.videoplatform.job_questionnaire_config_api import JobQuestionnaireConfigApi
from phenom.api.videoplatform.questionnaire_templates_api import QuestionnaireTemplatesApi
from phenom.api.videoplatform.questions_api import QuestionsApi
from phenom.api.videoplatform.review_api import ReviewApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.videoplatform.models.bad_request import BadRequest
from phenom.api.videoplatform.models.create_question_request import CreateQuestionRequest
from phenom.api.videoplatform.models.create_question_request_settings import CreateQuestionRequestSettings
from phenom.api.videoplatform.models.create_question_request_settings_number_of_choice import CreateQuestionRequestSettingsNumberOfChoice
from phenom.api.videoplatform.models.create_question_response import CreateQuestionResponse
from phenom.api.videoplatform.models.create_question_response_data import CreateQuestionResponseData
from phenom.api.videoplatform.models.create_question_response_data_question_translations import CreateQuestionResponseDataQuestionTranslations
from phenom.api.videoplatform.models.create_questionnaire_request import CreateQuestionnaireRequest
from phenom.api.videoplatform.models.create_questionnaire_response import CreateQuestionnaireResponse
from phenom.api.videoplatform.models.create_questionnaire_response_data import CreateQuestionnaireResponseData
from phenom.api.videoplatform.models.delete_question_response import DeleteQuestionResponse
from phenom.api.videoplatform.models.delete_questionnaire_response import DeleteQuestionnaireResponse
from phenom.api.videoplatform.models.disable_interview_request import DisableInterviewRequest
from phenom.api.videoplatform.models.disable_interview_request_assessments import DisableInterviewRequestAssessments
from phenom.api.videoplatform.models.disable_interview_response import DisableInterviewResponse
from phenom.api.videoplatform.models.disable_interview_response_data import DisableInterviewResponseData
from phenom.api.videoplatform.models.enable_one_way_interview_request import EnableOneWayInterviewRequest
from phenom.api.videoplatform.models.enable_one_way_interview_response import EnableOneWayInterviewResponse
from phenom.api.videoplatform.models.enable_one_way_interview_response_data import EnableOneWayInterviewResponseData
from phenom.api.videoplatform.models.enable_one_way_interview_response_data_auto_reminder_data import EnableOneWayInterviewResponseDataAutoReminderData
from phenom.api.videoplatform.models.enable_one_way_interview_response_data_odva_template_config import EnableOneWayInterviewResponseDataOdvaTemplateConfig
from phenom.api.videoplatform.models.get_all_evaluations_for_interview_id import GetAllEvaluationsForInterviewId
from phenom.api.videoplatform.models.get_all_evaluations_for_interview_id_data import GetAllEvaluationsForInterviewIdData
from phenom.api.videoplatform.models.get_all_evaluations_for_interview_id_data_answer_ratings import GetAllEvaluationsForInterviewIdDataAnswerRatings
from phenom.api.videoplatform.models.get_all_evaluations_for_interview_id_data_evaluations import GetAllEvaluationsForInterviewIdDataEvaluations
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response import GetAllInterviewsForCandidateResponse
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data import GetAllInterviewsForCandidateResponseData
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data_candidate_info import GetAllInterviewsForCandidateResponseDataCandidateInfo
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data_interview_details import GetAllInterviewsForCandidateResponseDataInterviewDetails
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data_interview_details_job_details import GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data_interviews import GetAllInterviewsForCandidateResponseDataInterviews
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data_questions import GetAllInterviewsForCandidateResponseDataQuestions
from phenom.api.videoplatform.models.get_all_interviews_for_candidate_response_data_recruiter_details import GetAllInterviewsForCandidateResponseDataRecruiterDetails
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response import GetAllInterviewsForJobIdResponse
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data import GetAllInterviewsForJobIdResponseData
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data_candidate_info import GetAllInterviewsForJobIdResponseDataCandidateInfo
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data_interview_details import GetAllInterviewsForJobIdResponseDataInterviewDetails
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data_interview_details_job_details import GetAllInterviewsForJobIdResponseDataInterviewDetailsJobDetails
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data_interviews import GetAllInterviewsForJobIdResponseDataInterviews
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data_questions import GetAllInterviewsForJobIdResponseDataQuestions
from phenom.api.videoplatform.models.get_all_interviews_for_job_id_response_data_recruiter_details import GetAllInterviewsForJobIdResponseDataRecruiterDetails
from phenom.api.videoplatform.models.get_all_question_types import GetAllQuestionTypes
from phenom.api.videoplatform.models.get_all_question_types_data import GetAllQuestionTypesData
from phenom.api.videoplatform.models.get_all_question_types_data_knockout_question_configuration import GetAllQuestionTypesDataKnockoutQuestionConfiguration
from phenom.api.videoplatform.models.get_all_question_types_data_multi_choice_settings import GetAllQuestionTypesDataMultiChoiceSettings
from phenom.api.videoplatform.models.get_all_question_types_data_question_types import GetAllQuestionTypesDataQuestionTypes
from phenom.api.videoplatform.models.get_all_questionnaires_response import GetAllQuestionnairesResponse
from phenom.api.videoplatform.models.get_all_questionnaires_response_data import GetAllQuestionnairesResponseData
from phenom.api.videoplatform.models.get_all_questionnaires_response_data_locales import GetAllQuestionnairesResponseDataLocales
from phenom.api.videoplatform.models.get_all_questionnaires_response_data_questionnaire_details import GetAllQuestionnairesResponseDataQuestionnaireDetails
from phenom.api.videoplatform.models.get_all_questionnaires_response_data_questions import GetAllQuestionnairesResponseDataQuestions
from phenom.api.videoplatform.models.get_all_questions_response import GetAllQuestionsResponse
from phenom.api.videoplatform.models.get_all_questions_response_data import GetAllQuestionsResponseData
from phenom.api.videoplatform.models.get_all_questions_response_data_question_translations import GetAllQuestionsResponseDataQuestionTranslations
from phenom.api.videoplatform.models.get_all_questions_response_data_questions import GetAllQuestionsResponseDataQuestions
from phenom.api.videoplatform.models.get_all_questions_response_data_settings import GetAllQuestionsResponseDataSettings
from phenom.api.videoplatform.models.get_evaluations_by_interview_id_and_recruiter_id_response import GetEvaluationsByInterviewIdAndRecruiterIdResponse
from phenom.api.videoplatform.models.get_evaluations_by_interview_id_and_recruiter_id_response_data import GetEvaluationsByInterviewIdAndRecruiterIdResponseData
from phenom.api.videoplatform.models.get_evaluations_for_interview_response import GetEvaluationsForInterviewResponse
from phenom.api.videoplatform.models.get_evaluations_for_interview_response_data import GetEvaluationsForInterviewResponseData
from phenom.api.videoplatform.models.get_evaluations_for_interview_response_data_answer_ratings import GetEvaluationsForInterviewResponseDataAnswerRatings
from phenom.api.videoplatform.models.get_evaluations_for_interview_response_data_evaluations import GetEvaluationsForInterviewResponseDataEvaluations
from phenom.api.videoplatform.models.get_interview_details_for_evaluating_response import GetInterviewDetailsForEvaluatingResponse
from phenom.api.videoplatform.models.get_interview_details_for_evaluating_response_data import GetInterviewDetailsForEvaluatingResponseData
from phenom.api.videoplatform.models.get_interview_details_for_evaluating_response_data_candidate_info import GetInterviewDetailsForEvaluatingResponseDataCandidateInfo
from phenom.api.videoplatform.models.get_interview_details_for_evaluating_response_data_interview_details import GetInterviewDetailsForEvaluatingResponseDataInterviewDetails
from phenom.api.videoplatform.models.get_interview_details_for_evaluating_response_data_interview_details_job_details import GetInterviewDetailsForEvaluatingResponseDataInterviewDetailsJobDetails
from phenom.api.videoplatform.models.get_interview_details_for_evaluating_response_data_questions import GetInterviewDetailsForEvaluatingResponseDataQuestions
from phenom.api.videoplatform.models.get_interview_details_response import GetInterviewDetailsResponse
from phenom.api.videoplatform.models.get_interview_details_response_data import GetInterviewDetailsResponseData
from phenom.api.videoplatform.models.get_interview_details_response_data_candidate_info import GetInterviewDetailsResponseDataCandidateInfo
from phenom.api.videoplatform.models.get_interview_details_response_data_interview_details import GetInterviewDetailsResponseDataInterviewDetails
from phenom.api.videoplatform.models.get_interview_details_response_data_interview_details_job_details import GetInterviewDetailsResponseDataInterviewDetailsJobDetails
from phenom.api.videoplatform.models.get_interview_details_response_data_questions import GetInterviewDetailsResponseDataQuestions
from phenom.api.videoplatform.models.get_interview_details_response_data_recruiter_details import GetInterviewDetailsResponseDataRecruiterDetails
from phenom.api.videoplatform.models.get_one_way_interview_config_response import GetOneWayInterviewConfigResponse
from phenom.api.videoplatform.models.get_one_way_interview_config_response_data import GetOneWayInterviewConfigResponseData
from phenom.api.videoplatform.models.get_one_way_interview_config_response_data_auto_reminder_data import GetOneWayInterviewConfigResponseDataAutoReminderData
from phenom.api.videoplatform.models.get_one_way_interview_config_response_data_odva_template_config import GetOneWayInterviewConfigResponseDataOdvaTemplateConfig
from phenom.api.videoplatform.models.get_question_details_response import GetQuestionDetailsResponse
from phenom.api.videoplatform.models.get_question_details_response_data import GetQuestionDetailsResponseData
from phenom.api.videoplatform.models.get_question_details_response_question_translations import GetQuestionDetailsResponseQuestionTranslations
from phenom.api.videoplatform.models.get_question_details_response_settings import GetQuestionDetailsResponseSettings
from phenom.api.videoplatform.models.get_question_details_response_settings_number_of_choice import GetQuestionDetailsResponseSettingsNumberOfChoice
from phenom.api.videoplatform.models.get_questionnaire_details_response import GetQuestionnaireDetailsResponse
from phenom.api.videoplatform.models.get_questionnaire_details_response_data import GetQuestionnaireDetailsResponseData
from phenom.api.videoplatform.models.get_questionnaire_details_response_data_locales import GetQuestionnaireDetailsResponseDataLocales
from phenom.api.videoplatform.models.get_questionnaire_details_response_data_question_translations import GetQuestionnaireDetailsResponseDataQuestionTranslations
from phenom.api.videoplatform.models.get_questionnaire_details_response_data_questionnaire_details import GetQuestionnaireDetailsResponseDataQuestionnaireDetails
from phenom.api.videoplatform.models.get_questionnaire_details_response_data_questions import GetQuestionnaireDetailsResponseDataQuestions
from phenom.api.videoplatform.models.give_evaluation_request import GiveEvaluationRequest
from phenom.api.videoplatform.models.give_evaluation_request_answer_ratings import GiveEvaluationRequestAnswerRatings
from phenom.api.videoplatform.models.give_evaluation_response import GiveEvaluationResponse
from phenom.api.videoplatform.models.give_evaluation_response_data import GiveEvaluationResponseData
from phenom.api.videoplatform.models.give_evaluation_response_data_answer_ratings import GiveEvaluationResponseDataAnswerRatings
from phenom.api.videoplatform.models.internal_error_response import InternalErrorResponse
from phenom.api.videoplatform.models.invite_candidate import InviteCandidate
from phenom.api.videoplatform.models.invite_candidate_response import InviteCandidateResponse
from phenom.api.videoplatform.models.invite_candidate_response_data import InviteCandidateResponseData
from phenom.api.videoplatform.models.invite_candidate_response_data_auto_reminder_info import InviteCandidateResponseDataAutoReminderInfo
from phenom.api.videoplatform.models.invite_candidate_response_data_invites import InviteCandidateResponseDataInvites
from phenom.api.videoplatform.models.update_question_request import UpdateQuestionRequest
from phenom.api.videoplatform.models.update_question_response import UpdateQuestionResponse
from phenom.api.videoplatform.models.update_question_response_data import UpdateQuestionResponseData
from phenom.api.videoplatform.models.update_questionnaire_request import UpdateQuestionnaireRequest
from phenom.api.videoplatform.models.update_questionnaire_request_locales import UpdateQuestionnaireRequestLocales
from phenom.api.videoplatform.models.update_questionnaire_request_question_translations import UpdateQuestionnaireRequestQuestionTranslations
from phenom.api.videoplatform.models.update_questionnaire_request_questionnaire_details import UpdateQuestionnaireRequestQuestionnaireDetails
from phenom.api.videoplatform.models.update_questionnaire_request_questions import UpdateQuestionnaireRequestQuestions
from phenom.api.videoplatform.models.update_questionnaire_response import UpdateQuestionnaireResponse
from phenom.api.videoplatform.models.update_questionnaire_response_data import UpdateQuestionnaireResponseData



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'location': 'str',
        'title': 'str',
        'job_id': 'str'
    }

    attribute_map = {
        'category': 'category',
        'location': 'location',
        'title': 'title',
        'job_id': 'jobId'
    }

    def __init__(self, category=None, location=None, title=None, job_id=None):  # noqa: E501
        """GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails - a model defined in Swagger"""  # noqa: E501
        self._category = None
        self._location = None
        self._title = None
        self._job_id = None
        self.discriminator = None
        self.category = category
        self.location = location
        self.title = title
        self.job_id = job_id

    @property
    def category(self):
        """Gets the category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job category.  # noqa: E501

        :return: The category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job category.  # noqa: E501

        :param category: The category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def location(self):
        """Gets the location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job posted location.  # noqa: E501

        :return: The location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job posted location.  # noqa: E501

        :param location: The location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def title(self):
        """Gets the title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job title.  # noqa: E501

        :return: The title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job title.  # noqa: E501

        :param title: The title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def job_id(self):
        """Gets the job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job id of the job.  # noqa: E501

        :return: The job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job id of the job.  # noqa: E501

        :param job_id: The job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.servicehubpublic.user_management_api import UserManagementApi
from phenom.api.servicehubscim.scim_api import SCIMApi

class UserManagement(object):
    def __init__(self, token, gateway_url, apikey=None):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def user_management(self):
        return UserManagementApi(self.__token, self.__gateway_url, self.__apikey)

    def scim_api(self):
        return SCIMApi(self.__token, self.__gateway_url, self.__apikey)


# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectAssociationsResponsePagination(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'size': 'float',
        '_from': 'float',
        'total_count': 'float'
    }

    attribute_map = {
        'size': 'size',
        '_from': 'from',
        'total_count': 'totalCount'
    }

    def __init__(self, size=None, _from=None, total_count=None):  # noqa: E501
        """GetProjectAssociationsResponsePagination - a model defined in Swagger"""  # noqa: E501
        self._size = None
        self.__from = None
        self._total_count = None
        self.discriminator = None
        self.size = size
        self._from = _from
        self.total_count = total_count

    @property
    def size(self):
        """Gets the size of this GetProjectAssociationsResponsePagination.  # noqa: E501

        Number of candidateIds per page in the paginated response.  # noqa: E501

        :return: The size of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this GetProjectAssociationsResponsePagination.

        Number of candidateIds per page in the paginated response.  # noqa: E501

        :param size: The size of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :type: float
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def _from(self):
        """Gets the _from of this GetProjectAssociationsResponsePagination.  # noqa: E501

        Index of the first candidateId in the current response.  # noqa: E501

        :return: The _from of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this GetProjectAssociationsResponsePagination.

        Index of the first candidateId in the current response.  # noqa: E501

        :param _from: The _from of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :type: float
        """
        if _from is None:
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def total_count(self):
        """Gets the total_count of this GetProjectAssociationsResponsePagination.  # noqa: E501

        Total count of candidateIds.  # noqa: E501

        :return: The total_count of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :rtype: float
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this GetProjectAssociationsResponsePagination.

        Total count of candidateIds.  # noqa: E501

        :param total_count: The total_count of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :type: float
        """
        if total_count is None:
            raise ValueError("Invalid value for `total_count`, must not be `None`")  # noqa: E501

        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectAssociationsResponsePagination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectAssociationsResponsePagination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobResponseJobTypeFields(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_type': 'str',
        'is_intern': 'bool',
        'experience_type': 'str',
        'is_entrylevel': 'bool'
    }

    attribute_map = {
        'job_type': 'jobType',
        'is_intern': 'isIntern',
        'experience_type': 'experienceType',
        'is_entrylevel': 'isEntrylevel'
    }

    def __init__(self, job_type=None, is_intern=None, experience_type=None, is_entrylevel=None):  # noqa: E501
        """JobResponseJobTypeFields - a model defined in Swagger"""  # noqa: E501
        self._job_type = None
        self._is_intern = None
        self._experience_type = None
        self._is_entrylevel = None
        self.discriminator = None
        if job_type is not None:
            self.job_type = job_type
        if is_intern is not None:
            self.is_intern = is_intern
        if experience_type is not None:
            self.experience_type = experience_type
        if is_entrylevel is not None:
            self.is_entrylevel = is_entrylevel

    @property
    def job_type(self):
        """Gets the job_type of this JobResponseJobTypeFields.  # noqa: E501

        Job type part-time/full-time.  # noqa: E501

        :return: The job_type of this JobResponseJobTypeFields.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this JobResponseJobTypeFields.

        Job type part-time/full-time.  # noqa: E501

        :param job_type: The job_type of this JobResponseJobTypeFields.  # noqa: E501
        :type: str
        """

        self._job_type = job_type

    @property
    def is_intern(self):
        """Gets the is_intern of this JobResponseJobTypeFields.  # noqa: E501

        Is intern job.  # noqa: E501

        :return: The is_intern of this JobResponseJobTypeFields.  # noqa: E501
        :rtype: bool
        """
        return self._is_intern

    @is_intern.setter
    def is_intern(self, is_intern):
        """Sets the is_intern of this JobResponseJobTypeFields.

        Is intern job.  # noqa: E501

        :param is_intern: The is_intern of this JobResponseJobTypeFields.  # noqa: E501
        :type: bool
        """

        self._is_intern = is_intern

    @property
    def experience_type(self):
        """Gets the experience_type of this JobResponseJobTypeFields.  # noqa: E501

        Experience Level.  # noqa: E501

        :return: The experience_type of this JobResponseJobTypeFields.  # noqa: E501
        :rtype: str
        """
        return self._experience_type

    @experience_type.setter
    def experience_type(self, experience_type):
        """Sets the experience_type of this JobResponseJobTypeFields.

        Experience Level.  # noqa: E501

        :param experience_type: The experience_type of this JobResponseJobTypeFields.  # noqa: E501
        :type: str
        """

        self._experience_type = experience_type

    @property
    def is_entrylevel(self):
        """Gets the is_entrylevel of this JobResponseJobTypeFields.  # noqa: E501

        Is entry level job.  # noqa: E501

        :return: The is_entrylevel of this JobResponseJobTypeFields.  # noqa: E501
        :rtype: bool
        """
        return self._is_entrylevel

    @is_entrylevel.setter
    def is_entrylevel(self, is_entrylevel):
        """Sets the is_entrylevel of this JobResponseJobTypeFields.

        Is entry level job.  # noqa: E501

        :param is_entrylevel: The is_entrylevel of this JobResponseJobTypeFields.  # noqa: E501
        :type: bool
        """

        self._is_entrylevel = is_entrylevel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobResponseJobTypeFields, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponseJobTypeFields):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateEvaluationsOnJobDataCandidateEvaluations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'form_id': 'str',
        'form_name': 'str',
        'average_rating': 'str',
        'last_evaluated_date': 'str',
        'form_feedback': 'list[CandidateEvaluationsOnJobDataFormFeedback]'
    }

    attribute_map = {
        'form_id': 'formId',
        'form_name': 'formName',
        'average_rating': 'averageRating',
        'last_evaluated_date': 'lastEvaluatedDate',
        'form_feedback': 'formFeedback'
    }

    def __init__(self, form_id=None, form_name=None, average_rating=None, last_evaluated_date=None, form_feedback=None):  # noqa: E501
        """CandidateEvaluationsOnJobDataCandidateEvaluations - a model defined in Swagger"""  # noqa: E501
        self._form_id = None
        self._form_name = None
        self._average_rating = None
        self._last_evaluated_date = None
        self._form_feedback = None
        self.discriminator = None
        if form_id is not None:
            self.form_id = form_id
        if form_name is not None:
            self.form_name = form_name
        if average_rating is not None:
            self.average_rating = average_rating
        if last_evaluated_date is not None:
            self.last_evaluated_date = last_evaluated_date
        if form_feedback is not None:
            self.form_feedback = form_feedback

    @property
    def form_id(self):
        """Gets the form_id of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501

        Evaluation form id.  # noqa: E501

        :return: The form_id of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this CandidateEvaluationsOnJobDataCandidateEvaluations.

        Evaluation form id.  # noqa: E501

        :param form_id: The form_id of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._form_id = form_id

    @property
    def form_name(self):
        """Gets the form_name of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501

        Evaluation form name.  # noqa: E501

        :return: The form_name of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._form_name

    @form_name.setter
    def form_name(self, form_name):
        """Sets the form_name of this CandidateEvaluationsOnJobDataCandidateEvaluations.

        Evaluation form name.  # noqa: E501

        :param form_name: The form_name of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._form_name = form_name

    @property
    def average_rating(self):
        """Gets the average_rating of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501

        Evaluation average rating.  # noqa: E501

        :return: The average_rating of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._average_rating

    @average_rating.setter
    def average_rating(self, average_rating):
        """Sets the average_rating of this CandidateEvaluationsOnJobDataCandidateEvaluations.

        Evaluation average rating.  # noqa: E501

        :param average_rating: The average_rating of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._average_rating = average_rating

    @property
    def last_evaluated_date(self):
        """Gets the last_evaluated_date of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501

        Evaluation last evaluated date.  # noqa: E501

        :return: The last_evaluated_date of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :rtype: str
        """
        return self._last_evaluated_date

    @last_evaluated_date.setter
    def last_evaluated_date(self, last_evaluated_date):
        """Sets the last_evaluated_date of this CandidateEvaluationsOnJobDataCandidateEvaluations.

        Evaluation last evaluated date.  # noqa: E501

        :param last_evaluated_date: The last_evaluated_date of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :type: str
        """

        self._last_evaluated_date = last_evaluated_date

    @property
    def form_feedback(self):
        """Gets the form_feedback of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501

        Form feedback details.  # noqa: E501

        :return: The form_feedback of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :rtype: list[CandidateEvaluationsOnJobDataFormFeedback]
        """
        return self._form_feedback

    @form_feedback.setter
    def form_feedback(self, form_feedback):
        """Sets the form_feedback of this CandidateEvaluationsOnJobDataCandidateEvaluations.

        Form feedback details.  # noqa: E501

        :param form_feedback: The form_feedback of this CandidateEvaluationsOnJobDataCandidateEvaluations.  # noqa: E501
        :type: list[CandidateEvaluationsOnJobDataFormFeedback]
        """

        self._form_feedback = form_feedback

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateEvaluationsOnJobDataCandidateEvaluations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateEvaluationsOnJobDataCandidateEvaluations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class DisableInterviewResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'error_message': 'object',
        'candidate_id': 'str',
        'video_screen_id': 'str'
    }

    attribute_map = {
        'status': 'status',
        'error_message': 'errorMessage',
        'candidate_id': 'candidateId',
        'video_screen_id': 'videoScreenId'
    }

    def __init__(self, status=None, error_message=None, candidate_id=None, video_screen_id=None):  # noqa: E501
        """DisableInterviewResponseData - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._error_message = None
        self._candidate_id = None
        self._video_screen_id = None
        self.discriminator = None
        self.status = status
        self.error_message = error_message
        self.candidate_id = candidate_id
        self.video_screen_id = video_screen_id

    @property
    def status(self):
        """Gets the status of this DisableInterviewResponseData.  # noqa: E501

        You will get Success or Failure.  # noqa: E501

        :return: The status of this DisableInterviewResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DisableInterviewResponseData.

        You will get Success or Failure.  # noqa: E501

        :param status: The status of this DisableInterviewResponseData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def error_message(self):
        """Gets the error_message of this DisableInterviewResponseData.  # noqa: E501


        :return: The error_message of this DisableInterviewResponseData.  # noqa: E501
        :rtype: object
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this DisableInterviewResponseData.


        :param error_message: The error_message of this DisableInterviewResponseData.  # noqa: E501
        :type: object
        """
        if error_message is None:
            raise ValueError("Invalid value for `error_message`, must not be `None`")  # noqa: E501

        self._error_message = error_message

    @property
    def candidate_id(self):
        """Gets the candidate_id of this DisableInterviewResponseData.  # noqa: E501

        Candidate id whose interview is disabled.  # noqa: E501

        :return: The candidate_id of this DisableInterviewResponseData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this DisableInterviewResponseData.

        Candidate id whose interview is disabled.  # noqa: E501

        :param candidate_id: The candidate_id of this DisableInterviewResponseData.  # noqa: E501
        :type: str
        """
        if candidate_id is None:
            raise ValueError("Invalid value for `candidate_id`, must not be `None`")  # noqa: E501

        self._candidate_id = candidate_id

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this DisableInterviewResponseData.  # noqa: E501

        This is the interview id.  # noqa: E501

        :return: The video_screen_id of this DisableInterviewResponseData.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this DisableInterviewResponseData.

        This is the interview id.  # noqa: E501

        :param video_screen_id: The video_screen_id of this DisableInterviewResponseData.  # noqa: E501
        :type: str
        """
        if video_screen_id is None:
            raise ValueError("Invalid value for `video_screen_id`, must not be `None`")  # noqa: E501

        self._video_screen_id = video_screen_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DisableInterviewResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisableInterviewResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ProfileMatchingResponseJobs(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description_teaser': 'str',
        'title': 'str',
        'category': 'str',
        'job_id': 'str',
        'posted_date': 'str',
        'location_data': 'ProfileMatchingResponseLocationData',
        'fitlevel': 'str',
        'skill_gap': 'ProfileMatchingResponseSkillGap'
    }

    attribute_map = {
        'description_teaser': 'descriptionTeaser',
        'title': 'title',
        'category': 'category',
        'job_id': 'jobId',
        'posted_date': 'postedDate',
        'location_data': 'locationData',
        'fitlevel': 'fitlevel',
        'skill_gap': 'skillGap'
    }

    def __init__(self, description_teaser=None, title=None, category=None, job_id=None, posted_date=None, location_data=None, fitlevel=None, skill_gap=None):  # noqa: E501
        """ProfileMatchingResponseJobs - a model defined in Swagger"""  # noqa: E501
        self._description_teaser = None
        self._title = None
        self._category = None
        self._job_id = None
        self._posted_date = None
        self._location_data = None
        self._fitlevel = None
        self._skill_gap = None
        self.discriminator = None
        if description_teaser is not None:
            self.description_teaser = description_teaser
        if title is not None:
            self.title = title
        if category is not None:
            self.category = category
        if job_id is not None:
            self.job_id = job_id
        if posted_date is not None:
            self.posted_date = posted_date
        if location_data is not None:
            self.location_data = location_data
        if fitlevel is not None:
            self.fitlevel = fitlevel
        if skill_gap is not None:
            self.skill_gap = skill_gap

    @property
    def description_teaser(self):
        """Gets the description_teaser of this ProfileMatchingResponseJobs.  # noqa: E501

        AI generated teaser for description of the recommended job.  # noqa: E501

        :return: The description_teaser of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: str
        """
        return self._description_teaser

    @description_teaser.setter
    def description_teaser(self, description_teaser):
        """Sets the description_teaser of this ProfileMatchingResponseJobs.

        AI generated teaser for description of the recommended job.  # noqa: E501

        :param description_teaser: The description_teaser of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: str
        """

        self._description_teaser = description_teaser

    @property
    def title(self):
        """Gets the title of this ProfileMatchingResponseJobs.  # noqa: E501

        Title of the recommended job.  # noqa: E501

        :return: The title of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ProfileMatchingResponseJobs.

        Title of the recommended job.  # noqa: E501

        :param title: The title of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def category(self):
        """Gets the category of this ProfileMatchingResponseJobs.  # noqa: E501

        Category to which the recommended job belongs to.  # noqa: E501

        :return: The category of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ProfileMatchingResponseJobs.

        Category to which the recommended job belongs to.  # noqa: E501

        :param category: The category of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def job_id(self):
        """Gets the job_id of this ProfileMatchingResponseJobs.  # noqa: E501

        Unique identifier for a job.  # noqa: E501

        :return: The job_id of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this ProfileMatchingResponseJobs.

        Unique identifier for a job.  # noqa: E501

        :param job_id: The job_id of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def posted_date(self):
        """Gets the posted_date of this ProfileMatchingResponseJobs.  # noqa: E501

        Date on which the job was posted on careersite.  # noqa: E501

        :return: The posted_date of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: str
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this ProfileMatchingResponseJobs.

        Date on which the job was posted on careersite.  # noqa: E501

        :param posted_date: The posted_date of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: str
        """

        self._posted_date = posted_date

    @property
    def location_data(self):
        """Gets the location_data of this ProfileMatchingResponseJobs.  # noqa: E501


        :return: The location_data of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: ProfileMatchingResponseLocationData
        """
        return self._location_data

    @location_data.setter
    def location_data(self, location_data):
        """Sets the location_data of this ProfileMatchingResponseJobs.


        :param location_data: The location_data of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: ProfileMatchingResponseLocationData
        """

        self._location_data = location_data

    @property
    def fitlevel(self):
        """Gets the fitlevel of this ProfileMatchingResponseJobs.  # noqa: E501

        How well the job matches the user. Example: A, B and C.  # noqa: E501

        :return: The fitlevel of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: str
        """
        return self._fitlevel

    @fitlevel.setter
    def fitlevel(self, fitlevel):
        """Sets the fitlevel of this ProfileMatchingResponseJobs.

        How well the job matches the user. Example: A, B and C.  # noqa: E501

        :param fitlevel: The fitlevel of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: str
        """

        self._fitlevel = fitlevel

    @property
    def skill_gap(self):
        """Gets the skill_gap of this ProfileMatchingResponseJobs.  # noqa: E501


        :return: The skill_gap of this ProfileMatchingResponseJobs.  # noqa: E501
        :rtype: ProfileMatchingResponseSkillGap
        """
        return self._skill_gap

    @skill_gap.setter
    def skill_gap(self, skill_gap):
        """Sets the skill_gap of this ProfileMatchingResponseJobs.


        :param skill_gap: The skill_gap of this ProfileMatchingResponseJobs.  # noqa: E501
        :type: ProfileMatchingResponseSkillGap
        """

        self._skill_gap = skill_gap

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfileMatchingResponseJobs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfileMatchingResponseJobs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateEvaluationsDataInformation(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reason': 'list[str]',
        'evaluated_by_email': 'str',
        'rating': 'str',
        'recommendation': 'str',
        'additional_questions': 'list[QuestionAndAnswers]',
        'updated_date': 'str',
        'source': 'str',
        'evaluated_by_name': 'str'
    }

    attribute_map = {
        'reason': 'reason',
        'evaluated_by_email': 'evaluatedByEmail',
        'rating': 'rating',
        'recommendation': 'recommendation',
        'additional_questions': 'additionalQuestions',
        'updated_date': 'updatedDate',
        'source': 'source',
        'evaluated_by_name': 'evaluatedByName'
    }

    def __init__(self, reason=None, evaluated_by_email=None, rating=None, recommendation=None, additional_questions=None, updated_date=None, source=None, evaluated_by_name=None):  # noqa: E501
        """CandidateEvaluationsDataInformation - a model defined in Swagger"""  # noqa: E501
        self._reason = None
        self._evaluated_by_email = None
        self._rating = None
        self._recommendation = None
        self._additional_questions = None
        self._updated_date = None
        self._source = None
        self._evaluated_by_name = None
        self.discriminator = None
        if reason is not None:
            self.reason = reason
        if evaluated_by_email is not None:
            self.evaluated_by_email = evaluated_by_email
        if rating is not None:
            self.rating = rating
        if recommendation is not None:
            self.recommendation = recommendation
        if additional_questions is not None:
            self.additional_questions = additional_questions
        if updated_date is not None:
            self.updated_date = updated_date
        if source is not None:
            self.source = source
        if evaluated_by_name is not None:
            self.evaluated_by_name = evaluated_by_name

    @property
    def reason(self):
        """Gets the reason of this CandidateEvaluationsDataInformation.  # noqa: E501

        List of reason given by evaluator.  # noqa: E501

        :return: The reason of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: list[str]
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this CandidateEvaluationsDataInformation.

        List of reason given by evaluator.  # noqa: E501

        :param reason: The reason of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: list[str]
        """

        self._reason = reason

    @property
    def evaluated_by_email(self):
        """Gets the evaluated_by_email of this CandidateEvaluationsDataInformation.  # noqa: E501

        Email address of evaluator.  # noqa: E501

        :return: The evaluated_by_email of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: str
        """
        return self._evaluated_by_email

    @evaluated_by_email.setter
    def evaluated_by_email(self, evaluated_by_email):
        """Sets the evaluated_by_email of this CandidateEvaluationsDataInformation.

        Email address of evaluator.  # noqa: E501

        :param evaluated_by_email: The evaluated_by_email of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: str
        """

        self._evaluated_by_email = evaluated_by_email

    @property
    def rating(self):
        """Gets the rating of this CandidateEvaluationsDataInformation.  # noqa: E501

        Rating given by evaluator.  # noqa: E501

        :return: The rating of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: str
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this CandidateEvaluationsDataInformation.

        Rating given by evaluator.  # noqa: E501

        :param rating: The rating of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: str
        """

        self._rating = rating

    @property
    def recommendation(self):
        """Gets the recommendation of this CandidateEvaluationsDataInformation.  # noqa: E501

        Recommendation given by evaluator.  # noqa: E501

        :return: The recommendation of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: str
        """
        return self._recommendation

    @recommendation.setter
    def recommendation(self, recommendation):
        """Sets the recommendation of this CandidateEvaluationsDataInformation.

        Recommendation given by evaluator.  # noqa: E501

        :param recommendation: The recommendation of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: str
        """

        self._recommendation = recommendation

    @property
    def additional_questions(self):
        """Gets the additional_questions of this CandidateEvaluationsDataInformation.  # noqa: E501


        :return: The additional_questions of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: list[QuestionAndAnswers]
        """
        return self._additional_questions

    @additional_questions.setter
    def additional_questions(self, additional_questions):
        """Sets the additional_questions of this CandidateEvaluationsDataInformation.


        :param additional_questions: The additional_questions of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: list[QuestionAndAnswers]
        """

        self._additional_questions = additional_questions

    @property
    def updated_date(self):
        """Gets the updated_date of this CandidateEvaluationsDataInformation.  # noqa: E501

        Latest updated date.  # noqa: E501

        :return: The updated_date of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this CandidateEvaluationsDataInformation.

        Latest updated date.  # noqa: E501

        :param updated_date: The updated_date of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def source(self):
        """Gets the source of this CandidateEvaluationsDataInformation.  # noqa: E501

        Source of the evaluation.  # noqa: E501

        :return: The source of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this CandidateEvaluationsDataInformation.

        Source of the evaluation.  # noqa: E501

        :param source: The source of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def evaluated_by_name(self):
        """Gets the evaluated_by_name of this CandidateEvaluationsDataInformation.  # noqa: E501

        Evaluated by user's name.  # noqa: E501

        :return: The evaluated_by_name of this CandidateEvaluationsDataInformation.  # noqa: E501
        :rtype: str
        """
        return self._evaluated_by_name

    @evaluated_by_name.setter
    def evaluated_by_name(self, evaluated_by_name):
        """Sets the evaluated_by_name of this CandidateEvaluationsDataInformation.

        Evaluated by user's name.  # noqa: E501

        :param evaluated_by_name: The evaluated_by_name of this CandidateEvaluationsDataInformation.  # noqa: E501
        :type: str
        """

        self._evaluated_by_name = evaluated_by_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateEvaluationsDataInformation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateEvaluationsDataInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
